@@ -1,17 +1,41 @@
 import abc
-import inspect
 import typing
+
 from dataclasses import dataclass
 
 T = typing.TypeVar("T")
 
 
-@dataclass
+class BaseMatcher(abc.ABC):
+    """Abstract base class from which all matchers inherit."""
+
+    def __repr__(self):
+        args = ", ".join(f"{k}={repr(v)}" for k, v in vars(self).items() if v is not None)
+        return f"expyct.{self.__class__.__name__}({args})"
+
+    def __str__(self):
+        args = ", ".join(f"{k}={v}" for k, v in vars(self).items() if v is not None)
+        return f"{self.__class__.__name__}({args})"
+
+    def __eq__(self, other):
+        if isinstance(other, type(self)):
+            return vars(other) == vars(self)
+        return self._eq(other)
+
+    @abc.abstractmethod
+    def _eq(self, other):
+        # This method needs to be overriden by children
+        ...
+
+
 class MapBefore:
-    """Mixing for applying a function before checking equality."""
+    """Mixin for applying a function before checking equality.
+
+    This class is not meant to be used by itself.
+    """
 
     def __init__(self, map_before: typing.Optional[typing.Callable] = None):
-        """Mixing for applying a function before checking equality.
+        """Mixin for applying a function before checking equality.
 
         Args:
             map_before : the mapping function to apply
@@ -27,8 +51,8 @@ class MapBefore:
             return other
 
 
-@dataclass
-class Satisfies:
+@dataclass(repr=False, eq=False)
+class Satisfies(BaseMatcher):
     """Mixin for checking equality by using a predicate function.
 
     If `satisfies(obj)` returns `True`, then it is equal.
@@ -44,8 +68,8 @@ class Satisfies:
         """
         self.satisfies = satisfies
 
-    def __eq__(self, other):
-        if self.satisfies:
+    def _eq(self, other):
+        if self.satisfies is not None:
             try:
                 return self.satisfies(other)
             except Exception:
@@ -53,8 +77,8 @@ class Satisfies:
         return True
 
 
-@dataclass
-class Equals(typing.Generic[T]):
+@dataclass(repr=False, eq=False)
+class Equals(typing.Generic[T], BaseMatcher):
     """Mixin for checking equality using a specific object to compare against."""
 
     equals: typing.Optional[T] = None
@@ -67,15 +91,15 @@ class Equals(typing.Generic[T]):
         """
         self.equals = equals
 
-    def __eq__(self, other):
+    def _eq(self, other):
         if self.equals is not None:
             if not other == self.equals:
                 return False
         return True
 
 
-@dataclass
-class Vars:
+@dataclass(repr=False, eq=False)
+class Vars(BaseMatcher):
     """Mixin for checking the presence of specific object attributes.
 
     The attributes are compared as a dict. So anything that can be compared
@@ -92,15 +116,15 @@ class Vars:
         """
         self.vars = vars
 
-    def __eq__(self, other):
+    def _eq(self, other):
         if self.vars is not None:
             if not vars(other) == self.vars:
                 return False
         return True
 
 
-@dataclass
-class Optional:
+@dataclass(repr=False, eq=False)
+class Optional(BaseMatcher):
     """Mixin for matching with `None`."""
 
     optional: typing.Optional[bool] = None
@@ -113,7 +137,7 @@ class Optional:
         """
         self.optional = optional
 
-    def __eq__(self, other):
+    def _eq(self, other):
         if other is None:
             if self.optional is not None:
                 return self.optional is True
@@ -122,8 +146,8 @@ class Optional:
         return True
 
 
-@dataclass
-class Instance:
+@dataclass(repr=False, eq=False)
+class Instance(BaseMatcher):
     """Match any object that is a class instance."""
 
     type: typing.Optional[typing.Type] = None
@@ -143,24 +167,32 @@ class Instance:
         self.type = type
         self.instance_of = instance_of
 
-    def __eq__(self, other):
-        # TODO check
-        if (
-            inspect.ismodule(other)
-            or inspect.isclass(other)
-            or inspect.isfunction(other)
-            or inspect.ismethod(other)
-        ):
-            return False
+    def _eq(self, other):
         if self.type and type(other) != self.type:
             return False
         if self.instance_of and not isinstance(other, self.instance_of):
             return False
         return True
 
+    @property  # type: ignore
+    def __class__(self):
+        """
+        Allows Instance objects to pretend to be an instance of another class.
 
-@dataclass
-class Type:
+        For example:
+            `isinstance(Instance(type=float), float)` is true
+
+        This is needed for type-checking libraries like mypy.
+        """
+
+        fake_class = self.type or self.instance_of
+        if fake_class:
+            return fake_class
+        return type(self)
+
+
+@dataclass(repr=False, eq=False)
+class Type(BaseMatcher):
     """Match any object that is a type."""
 
     superclass_of: typing.Optional[typing.Type] = None
@@ -180,7 +212,7 @@ class Type:
         self.superclass_of = superclass_of
         self.subclass_of = subclass_of
 
-    def __eq__(self, other):
+    def _eq(self, other):
         if not (type(other) == type or type(other) == abc.ABCMeta):
             return False
         if self.superclass_of and not issubclass(self.superclass_of, other):
