@@ -4,7 +4,7 @@ from datetime import datetime, date, time, timedelta, timezone
 
 from dataclasses import dataclass
 
-from expyct.base import Equals, MapBefore, Satisfies, Optional
+from expyct.base import Equals, MapBefore, Satisfies, Optional, BaseMatcher
 
 if (3, 6) <= sys.version_info < (3, 7):
     # fromisoformat only became available in 3.7
@@ -16,8 +16,8 @@ if (3, 6) <= sys.version_info < (3, 7):
 T = typing.TypeVar("T")
 
 
-@dataclass
-class AfterBefore(typing.Generic[T]):
+@dataclass(repr=False, eq=False)
+class AfterBefore(typing.Generic[T], BaseMatcher):
     """Mixin for matching a `date`, `time`, or `datetime` that takes place after, before, or on
     given date/time. In other words, it is inclusive on both sides.
 
@@ -44,7 +44,7 @@ class AfterBefore(typing.Generic[T]):
         self.after = after
         self.before = before
 
-    def __eq__(self, other):
+    def _eq(self, other):
         if self.after is not None and not other >= self.after:
             return False
         if self.before is not None and not other <= self.before:
@@ -52,8 +52,8 @@ class AfterBefore(typing.Generic[T]):
         return True
 
 
-@dataclass
-class AfterBeforeStrict(typing.Generic[T]):
+@dataclass(repr=False, eq=False)
+class AfterBeforeStrict(typing.Generic[T], BaseMatcher):
     """Mixin for matching a `date`, `time`, or `datetime` that takes place after and/or before given
     date/time. In other words, it is exclusive on both sides."""
 
@@ -75,7 +75,7 @@ class AfterBeforeStrict(typing.Generic[T]):
         self.after_strict = after_strict
         self.before_strict = before_strict
 
-    def __eq__(self, other):
+    def _eq(self, other):
         if self.after_strict is not None and not other > self.after_strict:
             return False
         if self.before_strict is not None and not other < self.before_strict:
@@ -83,7 +83,7 @@ class AfterBeforeStrict(typing.Generic[T]):
         return True
 
 
-@dataclass
+@dataclass(repr=False, eq=False)
 class DateTime(
     Satisfies,
     AfterBeforeStrict[datetime],
@@ -91,6 +91,7 @@ class DateTime(
     Equals[datetime],
     Optional,
     MapBefore,
+    BaseMatcher,
     datetime,
 ):
     """Match any object that is an instance of `datetime`."""
@@ -131,27 +132,27 @@ class DateTime(
         self.before_strict = before_strict
         self.satisfies = satisfies
 
-    def __eq__(self, other):
+    def _eq(self, other):
         try:
             other = MapBefore.map(self, other)
         except Exception:
             return False
         if other is None:
-            return Optional.__eq__(self, other)
+            return Optional._eq(self, other)
         if not type(other) == datetime:
             return False
-        if not Equals.__eq__(self, other):
+        if not Equals._eq(self, other):
             return False
-        if not AfterBefore.__eq__(self, other):
+        if not AfterBefore._eq(self, other):
             return False
-        if not AfterBeforeStrict.__eq__(self, other):
+        if not AfterBeforeStrict._eq(self, other):
             return False
-        if not Satisfies.__eq__(self, other):
+        if not Satisfies._eq(self, other):
             return False
         return True
 
 
-@dataclass
+@dataclass(repr=False, eq=False)
 class DateTimeTz(
     Satisfies,
     AfterBeforeStrict[datetime],
@@ -159,6 +160,7 @@ class DateTimeTz(
     Equals[datetime],
     Optional,
     MapBefore,
+    BaseMatcher,
     datetime,
 ):
     """Match any object that is an instance of `datetime` and has timezone information (`tzinfo`).
@@ -213,13 +215,13 @@ class DateTimeTz(
     after_strict: typing.Optional[typing.Union[datetime, timedelta]] = None  # type: ignore
     before_strict: typing.Optional[typing.Union[datetime, timedelta]] = None  # type: ignore
 
-    def __eq__(self, other):
+    def _eq(self, other):
         try:
             other = MapBefore.map(self, other)
         except Exception:
             return False
         if other is None:
-            return Optional.__eq__(self, other)
+            return Optional._eq(self, other)
         if not type(other) == datetime:
             return False
         if other.tzinfo is None:
@@ -227,7 +229,7 @@ class DateTimeTz(
         if self.equals:
             if self.equals.tzinfo is None:
                 raise ValueError("equals is missing tzinfo")
-        if not Equals.__eq__(self, other):
+        if not Equals._eq(self, other):
             return False
         if self.before:
             self.before = DateTimeTz._handle_timedelta(self.before)
@@ -237,7 +239,7 @@ class DateTimeTz(
             self.after = DateTimeTz._handle_timedelta(self.after)
             if self.after.tzinfo is None:
                 raise ValueError("after is missing tzinfo")
-        if not AfterBefore.__eq__(self, other):
+        if not AfterBefore._eq(self, other):
             return False
         if self.before_strict:
             self.before_strict = DateTimeTz._handle_timedelta(self.before_strict)
@@ -247,9 +249,9 @@ class DateTimeTz(
             self.after_strict = DateTimeTz._handle_timedelta(self.after_strict)
             if self.after_strict.tzinfo is None:
                 raise ValueError("after_strict is missing tzinfo")
-        if not AfterBeforeStrict.__eq__(self, other):
+        if not AfterBeforeStrict._eq(self, other):
             return False
-        if not Satisfies.__eq__(self, other):
+        if not Satisfies._eq(self, other):
             return False
         return True
 
@@ -266,9 +268,16 @@ class DateTimeTz(
             return bound
 
 
-@dataclass
+@dataclass(repr=False, eq=False)
 class Date(
-    Satisfies, AfterBeforeStrict[date], AfterBefore[date], Equals[date], Optional, MapBefore, date
+    Satisfies,
+    AfterBeforeStrict[date],
+    AfterBefore[date],
+    Equals[date],
+    Optional,
+    MapBefore,
+    BaseMatcher,
+    date,
 ):
     """Match any object that is an instance of `date`."""
 
@@ -310,29 +319,36 @@ class Date(
         self.before_strict = before_strict
         self.satisfies = satisfies
 
-    def __eq__(self, other):
+    def _eq(self, other):
         try:
             other = MapBefore.map(self, other)
         except Exception:
             return False
         if other is None:
-            return Optional.__eq__(self, other)
+            return Optional._eq(self, other)
         if not type(other) == date:
             return False
-        if not Equals.__eq__(self, other):
+        if not Equals._eq(self, other):
             return False
-        if not AfterBefore.__eq__(self, other):
+        if not AfterBefore._eq(self, other):
             return False
-        if not AfterBeforeStrict.__eq__(self, other):
+        if not AfterBeforeStrict._eq(self, other):
             return False
-        if not Satisfies.__eq__(self, other):
+        if not Satisfies._eq(self, other):
             return False
         return True
 
 
-@dataclass
+@dataclass(repr=False, eq=False)
 class Time(
-    Satisfies, AfterBeforeStrict[time], AfterBefore[time], Equals[time], Optional, MapBefore, time
+    Satisfies,
+    AfterBeforeStrict[time],
+    AfterBefore[time],
+    Equals[time],
+    Optional,
+    MapBefore,
+    BaseMatcher,
+    time,
 ):
     """Match any object that is an instance of `time`."""
 
@@ -374,22 +390,22 @@ class Time(
         self.before_strict = before_strict
         self.satisfies = satisfies
 
-    def __eq__(self, other):
+    def _eq(self, other):
         try:
             other = MapBefore.map(self, other)
         except Exception:
             return False
         if other is None:
-            return Optional.__eq__(self, other)
+            return Optional._eq(self, other)
         if not type(other) == time:
             return False
-        if not Equals.__eq__(self, other):
+        if not Equals._eq(self, other):
             return False
-        if not AfterBefore.__eq__(self, other):
+        if not AfterBefore._eq(self, other):
             return False
-        if not AfterBeforeStrict.__eq__(self, other):
+        if not AfterBeforeStrict._eq(self, other):
             return False
-        if not Satisfies.__eq__(self, other):
+        if not Satisfies._eq(self, other):
             return False
         return True
 
